@@ -152,7 +152,7 @@ class DB:
     ID = 1 if ID == True else 0
     find = {"_id": ID}
     #find.update(data)
-    for data in mycol.find({}, find).limit(limit):
+    for data in mycol.find({}, data).limit(limit):
       lst.append(data)
     return lst
 
@@ -266,6 +266,9 @@ class DB:
       self._dbName = x
       for a, b in y.items():
         self._colName = a
-        x = DB._transferMany(self, {a: b})
+        if type(b) != dict:
+          x = DB._transferMany(self, {a: b})
+        else:
+          x = DB._transferMany(self, b)
         ids.append(x)
     return x
